@@ -25,6 +25,9 @@ class QueryManager:
         self.s3 = boto3.client('s3', region_name='ap-northeast-2')
 
     def execute(self, query: str, database: str) -> str:
+        # Remove trailing semicolon if present
+        query = query.strip().rstrip(';')
+
         response = self.athena.start_query_execution(
             QueryString=query,
             QueryExecutionContext={'Database': database},
@@ -38,14 +41,14 @@ class QueryManager:
             response = self.athena.get_query_execution(QueryExecutionId=query_id)
             status = response['QueryExecution']['Status']['State']
             if status == 'SUCCEEDED':
-                print("[Athena] Query succeeded")
+                elapsed_time = time.time() - start_time
+                print(f"[Athena] Query succeeded ({elapsed_time:.2f}s)")
                 break
             elif status in ['FAILED', 'CANCELLED']:
                 reason = response['QueryExecution']['Status'].get('StateChangeReason', 'Unknown')
                 raise AthenaQueryError(f"Query {status}: {reason}")
             elif (time.time() - start_time) > timeout:
                 raise TimeoutError("Query timed out")
-            print(f"[Athena] Query status: {status}..")
             time.sleep(interval)
         return response['QueryExecution']['ResultConfiguration']['OutputLocation']
 
@@ -76,7 +79,7 @@ class QueryManager:
                 # Convert to pandas if requested
                 result_df = df_polars.to_pandas() if output_format == "pandas" else df_polars
 
-            # Auto cleanup if enabled
+            # Auto cleanup if enabled (silent cleanup, no logs)
             cleanup_enabled = auto_cleanup if auto_cleanup is not None else self._auto_cleanup
             if cleanup_enabled:
                 try:
@@ -87,9 +90,8 @@ class QueryManager:
                         self.s3.delete_object(Bucket=bucket, Key=metadata_key)
                     except:
                         pass  # Metadata file might not exist
-                    print(f"[S3] Cleaned up query result: {result_location}")
                 except Exception as cleanup_error:
-                    print(f"[S3] Warning: Failed to cleanup query result: {cleanup_error}")
+                    pass  # Silent cleanup failure
 
             return result_df
         except Exception as e:
@@ -100,21 +102,33 @@ class QueryManager:
         self.wait_for_completion(query_id)
         return self.get_result(query_id, auto_cleanup=auto_cleanup, output_format=output_format)
 
-    def unload(self, query: str, database: str) -> list[str]:
+    def unload(self, query: str, database: str, unload_location: str = None) -> list[str]:
         query_id = self.execute(query, database)
         result_location = self.wait_for_completion(query_id)
-        
-        # Extract the base path for unloaded files
-        match = re.match(r's3://([^/]+)/(.+)', result_location)
+
+        # Use provided unload_location or extract from result_location
+        if unload_location:
+            search_location = unload_location
+        else:
+            # Extract the base path for unloaded files (legacy behavior)
+            match = re.match(r's3://([^/]+)/(.+)', result_location)
+            if not match:
+                raise ValueError(f"Invalid S3 result location: {result_location}")
+            bucket, key_prefix = match.groups()
+            base_prefix = key_prefix.rsplit('/', 1)[0] + '/'
+            search_location = f's3://{bucket}/{base_prefix}'
+
+        # Extract bucket and prefix from search location
+        match = re.match(r's3://([^/]+)/(.+)', search_location.rstrip('/'))
         if not match:
-            raise ValueError(f"Invalid S3 result location: {result_location}")
-        
-        bucket, key_prefix = match.groups()
-        
-        # List all files that were created by the UNLOAD operation
-        # UNLOAD creates files with names like: query_id/part-00000.parquet, query_id/part-00001.parquet, etc.
-        base_prefix = key_prefix.rsplit('/', 1)[0] + '/'
-        
+            raise ValueError(f"Invalid S3 location: {search_location}")
+
+        bucket, base_prefix = match.groups()
+        if not base_prefix.endswith('/'):
+            base_prefix += '/'
+
+        print(f"[UNLOAD] Searching for files in: s3://{bucket}/{base_prefix}")
+
         paginator = self.s3.get_paginator('list_objects_v2')
         page_iterator = paginator.paginate(Bucket=bucket, Prefix=base_prefix)
         
@@ -122,10 +136,10 @@ class QueryManager:
         for page in page_iterator:
             for obj in page.get('Contents', []):
                 key = obj['Key']
-                # Skip the metadata file created by Athena
-                if not key.endswith('.metadata'):
+                # Only include Parquet files (with or without .gz compression)
+                if key.endswith('.parquet') or key.endswith('.parquet.gz'):
                     unloaded_files.append(f's3://{bucket}/{key}')
-        
+
         return unloaded_files
 
     def delete_query_results_by_prefix(self, s3_prefix_url: str):
